@@ -11,30 +11,27 @@ OC.L10N.register(
     "Tasks" : "工作項目",
     "The Tasks app for Nextcloud" : "Nextcloud 的工作項目應用程式",
     "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「工作項目」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除工作項目、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。工作項目可在使用者間分享。工作項目可使用 CalDav 同步（每個工作項目列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的工作項目，只要按下每個日曆的下載按鈕就好。",
-    "Default list" : "預設列表",
-    "Visibility of Smart Collections" : "智慧型收藏的能見度",
     "Hidden" : "隱藏",
     "Visible" : "顯示",
     "Automatic" : "自動",
     "Tasks settings" : "工作項目設定",
+    "Default list" : "預設列表",
+    "Visibility of Smart Collections" : "智慧型收藏的能見度",
     "Share with users or groups" : "與使用者或群組分享",
     "No users or groups" : "沒有使用者或群組",
-    "Can edit" : "可以編輯",
-    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
     "Unable to delete the share." : "無法刪除共享.",
     "Unable to change permissions." : "無法變更權限。",
-    "Edit" : "編輯",
-    "Copy private link" : "複製私人連結",
-    "Copied" : "已複製",
-    "Cannot copy" : "無法複製",
-    "Export" : "匯出",
-    "Delete" : "刪除",
-    "Unshare" : "撤回分享",
-    "List name" : "列表名稱",
+    "Can edit" : "可以編輯",
+    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "這將會刪除日曆「{calendar}」與所有對應的活動與工作項目。",
     "This will unshare the calendar \"{calendar}\"." : "這將會取消共享日曆「{calendar}」。",
     "This will delete the list \"{list}\" and all corresponding tasks." : "這將會刪除列表「{list}」與所有對應的工作項目。",
     "This will unshare the list \"{list}\"." : "這將會取消共享列表「{list}」。",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
+    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除列表"],
+    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享列表"],
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
     "Share this calendar" : "分享此行事曆",
     "Share this list" : "分享此清單",
     "Calendar link copied to clipboard." : "複製日曆連結到剪貼簿",
@@ -45,19 +42,14 @@ OC.L10N.register(
     "An empty name is not allowed." : "不允許空白的名稱.",
     "An error occurred, unable to delete the calendar." : "遇到錯誤，無法刪除日曆。",
     "An error occurred, unable to delete the list." : "遇到錯誤，無法刪除列表。",
-    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
-    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
-    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除列表"],
-    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享列表"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
-    "Trash bin" : "回收桶",
-    "Loading deleted calendars, tasks and events." : "正在載入已刪除的日曆、工作項目與活動。",
-    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、工作項目或活動。",
-    "Name" : "名稱",
-    "Deleted" : "已刪除",
-    "Restore" : "還原",
-    "Delete permanently" : "永久刪除",
-    "Empty trash bin" : "清空回收桶",
+    "Edit" : "編輯",
+    "Copy private link" : "複製私人連結",
+    "Copied" : "已複製",
+    "Cannot copy" : "無法複製",
+    "Export" : "匯出",
+    "Delete" : "刪除",
+    "Unshare" : "撤回分享",
+    "List name" : "列表名稱",
     "Untitled task" : "未命名工作項目",
     "Untitled event" : "未命名活動",
     "Untitled journal" : "未命名日誌",
@@ -67,7 +59,40 @@ OC.L10N.register(
     "Could not delete calendar or event" : "無法刪除日曆或活動",
     "Could not restore calendar or event" : "無法還原日曆或活動",
     "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
+    "Empty trash bin" : "清空回收桶",
+    "Trash bin" : "回收桶",
+    "Loading deleted calendars, tasks and events." : "正在載入已刪除的日曆、工作項目與活動。",
+    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、工作項目或活動。",
+    "Name" : "名稱",
+    "Deleted" : "已刪除",
+    "Restore" : "還原",
+    "Delete permanently" : "永久刪除",
     "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的元素將於{numDays}天後刪除"],
+    "Create reminder" : "建立提醒",
+    "Update reminder" : "更新提醒",
+    "Set a reminder at a custom date and time:" : "在自訂日期與時間設定提醒：",
+    "Cancel" : "取消",
+    "This is a todo reminder." : "這是待辦事項提醒。",
+    "No reminders" : "無提醒",
+    "Notification" : "通知",
+    "Email" : "電子郵件",
+    "Audio notification" : "音訊通知",
+    "Other notification" : "其他通知",
+    "Edit time" : "編輯時間",
+    "Remove reminder" : "刪除提醒",
+    "Add reminder" : "新增提醒",
+    "Before the task starts" : "在任務開始前",
+    "Before the task is due" : "任務截止前",
+    "Select date and time" : "選取日期與時間",
+    "Go back" : "返回",
+    "Set a reminder relative to your tasks start date:" : "設定與您的任務開始日期相關的提醒：",
+    "Set a reminder relative to your tasks due date:" : "設定與您的任務截止日期相關的提醒：",
+    "before at" : "之前於",
+    "_second_::_seconds_" : ["秒"],
+    "_minute_::_minutes_" : ["分鐘"],
+    "_hour_::_hours_" : ["時"],
+    "_day_::_days_" : ["天"],
+    "_week_::_weeks_" : ["週"],
     "Select a calendar" : "選取行事曆",
     "No calendar matches the search." : "沒有與搜尋相符的日曆。",
     "Set date" : "設定日期",
@@ -78,13 +103,12 @@ OC.L10N.register(
     "Delete value" : "刪除值",
     "Add this as a new tag" : "將這個新增為新標籤",
     "No tag available. Create one!" : "沒有可用的標籤。建立一個！",
+    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} 個工作項目已被新增至「{calendar}」",
     "Create new tasks" : "建立新工作項目",
     "Create {numberOfTasks} tasks from pasted text" : "從貼上的文字建立 {numberOfTasks} 個工作項目",
-    "Cancel" : "取消",
     "Create tasks" : "建立工作項目",
     "Creating new tasks…" : "正在建立新的工作項目……",
     "Close" : "關閉",
-    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} 個工作項目已被新增至「{calendar}」",
     "Delete all completed tasks." : "刪除所有已完成的工作項目。",
     "Delete completed tasks." : "刪除已完成的工作項目。",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的工作項目。",
@@ -104,7 +128,6 @@ OC.L10N.register(
     "Loading the completed tasks of all lists might slow down the app." : "載入所有清單的已完成工作可能會拖慢應用程式的速度。",
     "Load the completed tasks of list \"{calendar}\"." : "載入「{calendar}」清單的已完成工作。",
     "Loading the completed tasks might slow down the app." : "載入已完成工作可能會拖慢應用程式的速度。",
-    "Change sort order" : "改變分類順序",
     "Relevance" : "關聯",
     "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、結束日期、優先程度、開始日期與摘要排序。",
     "Start date" : "開始日期",
@@ -121,19 +144,11 @@ OC.L10N.register(
     "Sort by priority and summary." : "按優先程度與摘要排序。",
     "Alphabetically" : "字母",
     "Sort by summary and priority." : "按摘要與優先程度排序。",
+    "Tags" : "標籤",
+    "Sort by tags." : "按照標籤排序。",
     "Manually" : "手動",
     "Sort by manual order." : "手動排序。",
-    "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
-    "Task is pinned" : "工作項目已釘選",
-    "Task has a note" : "工作項目有註記",
-    "{complete} % completed" : "{complete} % 完成",
-    "Add subtask" : "新增子工作項目",
-    "Show subtasks" : "顯示子工作項目",
-    "Hide subtasks" : "隱藏子工作項目",
-    "Show closed subtasks" : "顯示已關閉的子工作項目",
-    "Hide closed subtasks" : "隱藏已關閉的子工作項目",
-    "Delete task" : "刪除工作項目",
-    "Toggle starred" : "加上／移除星號",
+    "Change sort order" : "改變分類順序",
     "[Yesterday]" : "[昨天]",
     "[Today]" : "[今天]",
     "[Tomorrow]" : "[明天]",
@@ -149,38 +164,34 @@ OC.L10N.register(
     "[Completed tomorrow at] LT" : "[明天完成於] LT",
     "[Completed] L [at] LT" : "[完成] L [於] LT",
     "Add a subtask to \"{task}\"…" : "新增子工作項目到「{task}」……",
+    "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
+    "Task is pinned" : "工作項目已釘選",
+    "Task has a note" : "工作項目有註記",
+    "{complete} % completed" : "{complete} % 完成",
+    "Add subtask" : "新增子工作項目",
+    "Show subtasks" : "顯示子工作項目",
+    "Hide subtasks" : "隱藏子工作項目",
+    "Show closed subtasks" : "顯示已關閉的子工作項目",
+    "Hide closed subtasks" : "隱藏已關閉的子工作項目",
+    "Delete task" : "刪除工作項目",
+    "Toggle starred" : "加上／移除星號",
+    "_Task has one reminder_::_Task has {n} reminders_" : ["任務有 {n} 個提醒"],
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除工作項目"],
     "Task is cancelled" : "工作項目已被取消",
     "Task is completed" : "工作項目已完成",
     "Task is read-only" : "工作項目唯讀",
     "Task is not completed" : "工作項目未完成",
+    "\"{task}\" was added to \"{calendar}\"" : "「{task}」已被新增至「{calendar}」",
     "Create a new task" : "建立新工作項目",
     "Task summary" : "工作項目摘要",
     "Create task" : "建立工作項目",
     "Creating the new task…" : "正在建立新工作項目",
     "Open task" : "開啟工作項目",
-    "\"{task}\" was added to \"{calendar}\"" : "「{task}」已被新增至「{calendar}」",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 完成任務"],
     "Tomorrow" : "明天",
+    "An error occurred, unable to create the list." : "遇到錯誤，無法建立清單。",
     "Add List…" : "增加清單...",
     "New list" : "新清單",
-    "An error occurred, unable to create the list." : "遇到錯誤，無法建立清單。",
-    "All day" : "全天",
-    "Unpin" : "取消釘選",
-    "Pin" : "釘選",
-    "Show in Calendar" : "在日曆中顯示",
-    "Show in Deck" : "在 Deck 中顯示",
-    "Edit summary" : "編輯摘要",
-    "Details" : "詳細資料",
-    "Selecting a classification is forbidden, because the task was shared with you." : "因為工作已與您分享，因此您無法選取分類。",
-    "Select a classification" : "選取分類",
-    "Select a status" : "選取狀態",
-    "Set a location" : "設定位置",
-    "Set a URL" : "設定 URL",
-    "Select tags" : "選取標籤",
-    "Notes" : "註解",
-    "Reminders" : "提醒",
-    "Repeat" : "重複",
     "When shared show full event" : "分享的時候顯示完整活動",
     "When shared show only busy" : "分享的時候顯示忙碌中",
     "When shared hide this event" : "分享的時候隱藏這個活動",
@@ -210,9 +221,20 @@ OC.L10N.register(
     "Priority {priority}: high" : "優先程度 {priority}：高",
     "No priority assigned" : "未指定優先程度",
     "{percent} % completed" : "{percent} % 完成",
-    "No upcoming tasks" : "沒有接下來的工作",
-    "upcoming tasks" : "接下來的工作",
-    "No tasks today" : "今日無工作",
+    "All day" : "全天",
+    "Unpin" : "取消釘選",
+    "Pin" : "釘選",
+    "Show in Calendar" : "在日曆中顯示",
+    "Show in Deck" : "在 Deck 中顯示",
+    "Edit summary" : "編輯摘要",
+    "Details" : "詳細資料",
+    "Selecting a classification is forbidden, because the task was shared with you." : "因為工作已與您分享，因此您無法選取分類。",
+    "Select a classification" : "選取分類",
+    "Select a status" : "選取狀態",
+    "Set a location" : "設定位置",
+    "Set a URL" : "設定 URL",
+    "Select tags" : "選取標籤",
+    "Notes" : "註解",
     "Mark as done" : "標記為完成",
     "No due date assigned" : "未指定到期日",
     "[Due yesterday]" : "[昨天截止]",
@@ -223,6 +245,10 @@ OC.L10N.register(
     "[Due today at] LT" : "[今天到期於] LT",
     "[Due tomorrow at] LT" : "[明天到期於] LT",
     "[Due] L [at] LT" : "[截止] L [於] LT",
+    "No upcoming tasks" : "沒有接下來的工作",
+    "upcoming tasks" : "接下來的工作",
+    "No tasks today" : "今日無工作",
+    "Completion date must be in the past." : "完成日期必須在過去。",
     "Successfully created the task." : "成功建立工作項目。",
     "Could not delete the task." : "無法刪除工作項目。",
     "Synchronizing to the server." : "與伺服器同步。",
@@ -251,6 +277,16 @@ OC.L10N.register(
     "[Starts tomorrow at] LT" : "[明天開始於] LT",
     "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
     "[Started yesterday at] LT" : "[昨天開始於] LT",
-    "[Started on] LL [at] LT" : "[開始在] LL [於] LT"
+    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
+    "Midnight on the day the task starts" : "任務開始當天午夜",
+    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["{formattedHourMinute} 的任務前%n天"],
+    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["{formattedHourMinute} 的任務前%n週"],
+    "on the day of the task at {formattedHourMinute}" : "{formattedHourMinute} 的任務當天",
+    "at the task's start" : "任務開始時",
+    "when the task is due" : "任務截止時",
+    "{time} before the task starts" : "任務開始前 {time}",
+    "{time} before the task is due" : "任務截止前 {time}",
+    "{time} after the task starts" : "任務開始後 {time}",
+    "{time} after the task is due" : "任務截止後 {time}"
 },
 "nplurals=1; plural=0;");
